#
# spec file for package jless
#
# Copyright (c) 2022-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jless
Version:        0.9.0
Release:        1.4
Summary:        Pager for JSON (or YAML) data
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://jless.io/
Source:         https://github.com/PaulJuliusMartinez/jless/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  zstd
BuildRequires:  cargo
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.67
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(xcb)
BuildRequires:  python3-base

%description
JLess is a command-line JSON viewer designed for reading, exploring, and
searching through JSON data.

JLess will pretty print your JSON and apply syntax highlighting. Use it when
exploring external APIs, or debugging request payloads.

Expand and collapse Objects and Arrays to grasp the high- and low-level
structure of a JSON document. JLess has a large suite of vim-inspired commands
that make exploring data a breeze.

JLess supports full text regular-expression based search. Quickly find the data
you're looking for in long String values, or jump between values for the same
Object key.

%prep
%autosetup -p 1 -a 1
install -D -m 0644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
cargo install --no-track --root=%{buildroot}%{_prefix} --path .

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/jless

%changelog
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire rust >= 1.67 as indicated by upstream
  - this leads to builds for 15.4 being unresolvable instead of
    failing...
* Fri Sep 15 2023 Johannes Kastl <kastl@b1-systems.de>
- add BuildRequires for python3-base
* Wed Jul 19 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.0
  New Features:
  * A ys command to copy unescaped string literals to the
    clipboard.
  * A family of printing p commands, analogous to the y commands,
    that print simply content to the screen. Useful for viewing
    long string values, or if the clipboard functionality isn't
    working.
  * Line numbers! Both absolute and relative.
  * C and E commands, analogous to the existing c and e commands,
    for deeply collapsing/expanding values
- Use cargo-packaging instead of rust-packaging
* Tue Sep 27 2022 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.8.0
